Simple example with OAuth
-------------------------

To use this example you need to configure **config.py** with your twitter, google and azure
application key and secret. In case of azure, configure AZURE_TENANT_ID is required.
This is a simple example where a user authenticates using twitter or google
and the application is able to send tweets on behalf of the user.

- Install it::

	pip install flask-appbuilder
	git clone https://github.com/dpgaspar/Flask-AppBuilder-Skeleton.git

- Run it::

	fabmanager run


That's it!!
